@@ -1634,14 +1634,45 @@ def unhide_packages(prefix='/', force=False):
 
 XPAK_TMP = "/dev/shm/xpak"
 
+
+class tbz2(object):
+    """
+    Python3 portage.xpak.tbz2 simple wrapper
+    """
+    def __init__(self, tbzfile):
+        self.tbzfile = tbzfile
+
+    def _escape(self, s):
+        return s.replace("'","\\'")
+
+    def decompose(self, workdir):
+        p = process('/usr/bin/python3')
+        p.write("from portage.xpak import tbz2\n"
+                "tbz2('%s').decompose('%s')" % (
+                    self._escape(self.tbzfile),
+                    self._escape(workdir)))
+        p.stdin.close()
+        if not p.success():
+            raise PackageError(_("Failed to decompose %s") % self.tbzfile)
+
+    def compose(self, workdir):
+        p = process('/usr/bin/python3')
+        p.write("from portage.xpak import tbz2\n"
+                "tbz2('%s').compose('%s')" % (
+                    self._escape(self.tbzfile),
+                    self._escape(workdir)))
+        p.stdin.close()
+        if not p.success():
+            raise PackageError(_("Failed to compose %s") % self.tbzfile)
+
+
 class BinaryPackage(object):
     """
     Объект для модификации var/db файлов бинарного пакета
     """
     def __init__(self, xpak_fn, work_dn=XPAK_TMP):
-        from calculate.lib.cl_portage import xpak
         self.work_dn = work_dn
-        self.tbz2 = xpak.tbz2(xpak_fn)
+        self.tbz2 = tbz2(xpak_fn)
         self.tbz2.decompose(self.work_dn)
 
     def __setitem__(self, item, value):
